import { Injectable } from '@nestjs/common';
import { Exploit } from '@prisma/client';
import { PrismaService } from 'nestjs-prisma';
import { CreateExploitDto, SearchExploitsDto } from './dto';

@Injectable()
export class ExploitDAO {
  private readonly step = 12; // exploits appearance per page
  constructor(private prisma: PrismaService) {}

  async create(exploitData: CreateExploitDto): Promise<Exploit> {
    return this.prisma.exploit.create({
      data: exploitData,
    });
  }

  async get(id: string): Promise<Exploit> {
    return this.prisma.exploit.findUnique({
      where: { id },
    });
  }

  async getByUser(userId: string, page: number): Promise<Exploit[]> {
    return this.prisma.exploit.findMany({
      where: {
        authorUserId: userId,
      },
      skip: (page.valueOf() - 1) * 10,
      take: 10,
      orderBy: {
        createdAt: 'desc',
      },
    });
  }

  async searchByName(searchExploitsDto: SearchExploitsDto): Promise<Exploit[]> {
    // assume pageNo >= 1
    return this.prisma.exploit.findMany({
      take: this.step,
      skip: (searchExploitsDto.pageNo - 1) * this.step,
      where: {
        name: { startsWith: searchExploitsDto.name },
      },
      orderBy: {
        name: 'asc',
      },
    });
  }

  async verify(id: string): Promise<Exploit> {
    return this.prisma.exploit.update({
      where: { id },
      data: { verified: true },
    });
  }
}
